.. _spkg_4ti2:

4ti2: Algebraic, geometric and combinatorial problems on linear spaces
======================================================================

Description
-----------

A software package for algebraic, geometric and combinatorial problems
on linear spaces. Available at https://4ti2.github.io/.

License
-------

4ti2 is released under a GPL v2 license.


Upstream Contact
----------------

- https://4ti2.github.io/

- Raymond Hemmecke, TU Munich, Germany
- Matthias Köppe, UC Davis, CA, USA


Type
----

optional


Dependencies
------------

- $(MP_LIBRARY)
- :ref:`spkg_glpk`
- :ref:`spkg_zlib`

Version Information
-------------------

package-version.txt::

    1.6.13

See https://repology.org/project/4ti2/versions

Installation commands
---------------------

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i 4ti2

.. tab:: Arch Linux:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S 4ti2

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install 4ti2

.. tab:: Debian/Ubuntu:

   .. CODE-BLOCK:: bash

       $ sudo apt-get install 4ti2

.. tab:: Fedora/Redhat/CentOS:

   .. CODE-BLOCK:: bash

       $ sudo dnf install 4ti2 4ti2-devel

.. tab:: FreeBSD:

   .. CODE-BLOCK:: bash

       $ sudo pkg install math/4ti2

.. tab:: Gentoo Linux:

   .. CODE-BLOCK:: bash

       $ sudo emerge sci-mathematics/4ti2

.. tab:: mingw-w64:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S ${MINGW_PACKAGE_PREFIX}-4ti2

.. tab:: openSUSE:

   .. CODE-BLOCK:: bash

       $ sudo zypper install 4ti2 4ti2-devel


If the system package is installed, ``./configure`` will check if it can be used.
